@@ -1,8 +1,8 @@
 
-from helloapache import HelloApp
+from helloapache import HelloUI
 
-# The Region class acting as the root of the URL hierachy of your application:
-web.site_root = HelloApp       
+# The UserInterface class acting as the root of the URL hierachy of your application:
+web.site_root = HelloUI       
 
 # HTTP is served on port 80, and HTTPS on 443, except when in development!
 web.default_http_port = 80
